@@ -1,6 +1,8 @@
 from .pycirc import *
+from .factory import *
 del util
 del logops
 del pycirc
+del factory
 print("Loading builtin box cells..")
 load_builtin_box_cells()
